// Mobile Menu Toggle
const mobileMenu = document.querySelector('.mobile-menu');
const navLinks = document.querySelector('.nav-links');

mobileMenu.addEventListener('click', () => {
  navLinks.classList.toggle('active');
});

// Blog Posts Data
const blogPosts = [
  {
    title: 'Digital Nomad Life in Bali',
    excerpt: 'My experience working remotely from the Island of Gods...',
    image: 'bali.jpg',
    category: 'Travel'
  },
  {
    title: 'Web Development Trends 2024',
    excerpt: 'Latest technologies shaping the future of web development...',
    image: 'tech.jpg',
    category: 'Technology'
  },
  {
    title: 'Minimalist Travel Photography',
    excerpt: 'Tips for capturing stunning travel moments with less gear...',
    image: 'photo.jpg',
    category: 'Photography'
  }
];

// Populate Blog Posts
const blogGrid = document.getElementById('blogPosts');
blogPosts.forEach(post => {
  const article = document.createElement('article');
  article.className = 'blog-post';
  article.innerHTML = `
    <img src="${post.image}" alt="${post.title}">
    <div class="post-content">
      <span class="category">${post.category}</span>
      <h3>${post.title}</h3>
      <p>${post.excerpt}</p>
      <button class="read-more">Read More</button>
    </div>
  `;
  blogGrid.appendChild(article);
});

// Gallery Functionality
const galleryImages = [
  { src: 'paris.jpg', category: 'europe', caption: 'Eiffel Tower, Paris' },
  { src: 'tokyo.jpg', category: 'asia', caption: 'Shibuya Crossing, Tokyo' },
  { src: 'nyc.jpg', category: 'americas', caption: 'Times Square, New York' }
];

const galleryGrid = document.getElementById('galleryGrid');
const lightbox = document.getElementById('lightbox');
const lightboxImg = document.getElementById('lightboxImage');

// Populate Gallery
galleryImages.forEach(img => {
  const div = document.createElement('div');
  div.className = 'gallery-item';
  div.setAttribute('data-category', img.category);
  div.innerHTML = `
    <img src="${img.src}" alt="${img.caption}">
    <div class="caption">${img.caption}</div>
  `;
  div.addEventListener('click', () => {
    lightboxImg.src = img.src;
    lightboxImg.alt = img.caption;
    lightbox.style.display = 'block';
  });
  galleryGrid.appendChild(div);
});

// Close Lightbox
document.querySelector('.close-lightbox').addEventListener('click', () => {
  lightbox.style.display = 'none';
});

// Gallery Filters
document.querySelectorAll('.gallery-filters button').forEach(button => {
  button.addEventListener('click', () => {
    const filter = button.getAttribute('data-filter');
    document.querySelectorAll('.gallery-filters button').forEach(btn => {
      btn.classList.remove('active');
    });
    button.classList.add('active');
    
    document.querySelectorAll('.gallery-item').forEach(item => {
      if (filter === 'all' || item.getAttribute('data-category') === filter) {
        item.style.display = 'block';
      } else {
        item.style.display = 'none';
      }
    });
  });
});

// Form Submissions
document.getElementById('contactForm').addEventListener('submit', (e) => {
  e.preventDefault();
  // Add form submission logic here
  alert('Message sent successfully!');
});

document.getElementById('newsletterForm').addEventListener('submit', (e) => {
  e.preventDefault();
  // Add newsletter subscription logic here
  alert('Successfully subscribed to newsletter!');
});
